[PATCH 03/11] blspec: rename _hwdevice functions to _devicename

Sascha Hauer s.hauer at pengutronix.de
Mon Nov 4 09:04:22 EST 2013


Since it's not necessarily the hardware device this seems to
be a more appropriate name.

Signed-off-by: Sascha Hauer <s.hauer at pengutronix.de>
---
 commands/boot.c  |  2 +-
 common/blspec.c  | 10 +++++-----
 include/blspec.h |  4 ++--
 3 files changed, 8 insertions(+), 8 deletions(-)

diff --git a/commands/boot.c b/commands/boot.c
index 8105889..f2d9836 100644
--- a/commands/boot.c
+++ b/commands/boot.c
@@ -219,7 +219,7 @@ static int boot(const char *name)
 			goto out;
 		}
 
-		ret = blspec_boot_hwdevice(name, verbose, dryrun);
+		ret = blspec_boot_devicename(name, verbose, dryrun);
 		pr_err("%s: %s\n", name, strerror(-ret));
 		goto out;
 	}
diff --git a/include/blspec.h b/include/blspec.h
index aa836e6..a7b189a 100644
--- a/include/blspec.h
+++ b/include/blspec.h
@@ -31,12 +31,12 @@ int blspec_entry_save(struct blspec_entry *entry, const char *path);
 
 int blspec_boot(struct blspec_entry *entry, int verbose, int dryrun);
 
-int blspec_boot_hwdevice(const char *devname, int verbose, int dryrun);
+int blspec_boot_devicename(const char *devname, int verbose, int dryrun);
 
 void blspec_scan_devices(struct blspec *blspec);
 
 struct blspec_entry *blspec_entry_default(struct blspec *l);
-int blspec_scan_hwdevice(struct blspec *blspec, const char *devname);
+int blspec_scan_devicename(struct blspec *blspec, const char *devname);
 
 #define blspec_for_each_entry(blspec, entry) \
 	list_for_each_entry(entry, &blspec->entries, list)
diff --git a/common/blspec.c b/common/blspec.c
index dd8ec4b..8ae09a2 100644
--- a/common/blspec.c
+++ b/common/blspec.c
@@ -361,12 +361,12 @@ int blspec_scan_device(struct blspec *blspec, struct device_d *dev)
 }
 
 /*
  * blspec_scan_hwdevice - scan a hardware device for child cdevs
  *
  * Given a name of a hardware device this functions scans over all child
  * cdevs looking for blspec entries.
  */
-int blspec_scan_hwdevice(struct blspec *blspec, const char *devname)
+int blspec_scan_devicename(struct blspec *blspec, const char *devname)
 {
 	struct device_d *dev;
 
@@ -488,10 +488,10 @@ struct blspec_entry *blspec_entry_default(struct blspec *l)
 }
 
 /*
  * blspec_boot_hwdevice - scan hardware device for blspec entries and
  *                        start the best one.
  */
-int blspec_boot_hwdevice(const char *devname, int verbose, int dryrun)
+int blspec_boot_devicename(const char *devname, int verbose, int dryrun)
 {
 	struct blspec *blspec;
 	struct blspec_entry *e;
@@ -499,7 +499,7 @@ int blspec_boot_hwdevice(const char *devname, int verbose, int dryrun)
 
 	blspec = blspec_alloc();
 
-	ret = blspec_scan_hwdevice(blspec, devname);
+	ret = blspec_scan_devicename(blspec, devname);
 	if (ret)
 		return ret;
 
@@ -361,12 +361,12 @@ int blspec_scan_device(struct blspec *blspec, struct device_d *dev)
 
 /*
- * blspec_scan_hwdevice - scan a hardware device for child cdevs
+ * blspec_scan_devicename - scan a hardware device for child cdevs
  *
  * Given a name of a hardware device this functions scans over all child
@@ -488,10 +488,10 @@ struct blspec_entry *blspec_entry_default(struct blspec *l)
 
 /*
- * blspec_boot_hwdevice - scan hardware device for blspec entries and
+ * blspec_boot_devicename - scan hardware device for blspec entries and
  *                        start the best one.
  */
-- 
1.8.4.rc3




More information about the barebox mailing list